/**
 * JHOVE2 - Next-generation architecture for format-aware characterization
 *
 * Copyright (c) 2009 by The Regents of the University of California.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * o Neither the name of the University of California/California Digital
 *   Library, Ithaka Harbors/Portico, or Stanford University, nor the names of
 *   its contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.jhove2.module.format.icc.type;

import com.sleepycat.persist.model.Persistent;

/** ICC XY number, a set of two fixed unsigned u16Fixed16Numbers.
 * 
 * @author slabrams
 */
@Persistent
public class XYNumber
{
    /** X number. */
    protected U16Fixed16Number x;

    /** Y number. */
    protected U16Fixed16Number y;
 
    private XYNumber(){
    	super();
    }
    /** Instantiate a new <code>XYNumber</code>
     */
    public XYNumber(long x, long y) {
    	this();
        this.x = new U16Fixed16Number(x);
        this.y = new U16Fixed16Number(y);
    }
    
    /** Get X value.
     * @return X value
     */
    public U16Fixed16Number getX() {
        return this.x;
    }
    
    /** Get Y value.
     * @return Z value
     */
    public U16Fixed16Number getY() {
        return this.y;
    }
    
    /** String representation of the numbers.
     * @return String representation of the numbers
     */
    public String toString() {
        return this.x.toString() + ", " + this.y.toString() + ", ";
    }
}
