/**
 * JHOVE2 - Next-generation architecture for format-aware characterization
 *
 * Copyright (c) 2009 by The Regents of the University of California,
 * Ithaka Harbors, Inc., and The Board of Trustees of the Leland Stanford
 * Junior University.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 * o Neither the name of the University of California/California Digital
 *   Library, Ithaka Harbors/Portico, or Stanford University, nor the names of
 *   its contributors may be used to endorse or promote products derived from
 *   this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.jhove2.persist;

import java.util.List;

import org.jhove2.core.JHOVE2;
import org.jhove2.core.JHOVE2Exception;
import org.jhove2.module.Command;

/**
 * Manages Framework (JHOVE2) module persistence
 * @author smorrissey
 *
 */
public interface FrameworkAccessor extends ModuleAccessor {

	/**
	 * Get list of characterizing Commands
	 * @param jhove2 Application framework which executes Commands
	 * @return List of Commands
	 * @throws JHOVE2Exception
	 */
	public List<Command> getCommands(JHOVE2 jhove2) throws JHOVE2Exception;
	/**
	 * Set list of characterizing Commands
	 * @param jhove2 Application framework which executes Commands
	 * @param commands to be executd
	 * @return List of Commands
	 * @throws JHOVE2Exception
	 */
	public List<Command> setCommands(JHOVE2 jhove2, List<Command> commands) throws JHOVE2Exception;
	/**
	 * Add Command to list of Commands to be executed by framework
	 * @param jhove2 JHOVE2 framework
	 * @param command Command to be added
	 * @return Command that was added
	 * @throws JHOVE2Exception
	 */
	public Command addCommand(JHOVE2 jhove2, Command command)throws JHOVE2Exception;
	/**
	 * From Command from list of Commands to be executed by framework
	 * @param jhove2 JHOVE2 framework
	 * @param command Command to be removed from list of Commands to be executed by framework
	 * @return Command to be removed from list of Commands to be executed by framework
	 * @throws JHOVE2Exception
	 */
	public Command deleteCommand(JHOVE2 jhove2, Command command)throws JHOVE2Exception;
}
